# bibin

Trash/Untrash files and folders in command-line or as a library.
Follows relevant [freedesktop spec](https://specifications.freedesktop.org/trash-spec/1.0/).

## Install

    pipx install bibin

## Command-line example

TODO

## Library example

TODO

## Standard

- supports non-home dir trashes (for example on different partitions or removable drives)

## License

bibin is licensed under [WTFPLv2](COPYING.WTFPL).
